package com.chelvc.cloud.vehicle.server.controller;

import java.util.List;
import java.util.Map;

import com.chelvc.cloud.vehicle.client.constant.MerchantStatus;
import com.chelvc.cloud.vehicle.client.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantDetailDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantRankDTO;
import com.chelvc.cloud.vehicle.client.param.LocationQueryParam;
import com.chelvc.cloud.vehicle.client.param.MerchantModifyParam;
import com.chelvc.cloud.vehicle.client.param.MerchantPagingParam;
import com.chelvc.cloud.vehicle.client.param.MerchantQueryParam;
import com.chelvc.cloud.vehicle.client.param.MerchantRankParam;
import com.chelvc.cloud.vehicle.client.param.OmsCartItemPagingParam;
import com.chelvc.cloud.vehicle.client.param.ReportModifyParam;
import com.chelvc.cloud.vehicle.server.service.MerchantService;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 商家业务接口
 *
 * @author Woody
 * @date 2023/5/4
 */
@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class MerchantController {

    private final MerchantService merchantService;

    /**
     * 获取附近商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    @GetMapping("/merchant/listNearbyMerchants")
    public List<MerchantDTO> listNearbyMerchants(@SpringQueryMap LocationQueryParam param,
                                                 @RequestParam("size") int size) {
        return merchantService.listNearbyMerchants(param, size);
    }

    /**
     * 获取推荐商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    @GetMapping("/merchant/listRecommendMerchants")
    public List<MerchantDTO> listRecommendMerchants(@SpringQueryMap LocationQueryParam param,
                                                    @RequestParam("size") int size) {
        return merchantService.listRecommendMerchants(param, size);
    }

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家信息列表
     */
    @GetMapping("/merchant/listSimpleMerchants")
    public List<MerchantDTO> listSimpleMerchants(MerchantQueryParam param) {
        return merchantService.listSimpleMerchants(param);
    }

    /**
     * 获取商家详情
     *
     * @param id 商家ID
     * @return 商家详情
     */
    @GetMapping("/merchant/getMerchantDetail")
    public MerchantDetailDTO getMerchantDetail(@RequestParam("id") Long id) {
        return merchantService.getMerchantDetail(id);
    }

    /**
     * 获取商家详情
     *
     * @param id    商家ID
     * @param param 查询参数
     * @return 商家详情
     */
    @GetMapping("/merchant/queryMerchantDetail")
    public MerchantDetailDTO queryMerchantDetail(@RequestParam("id") Long id,
                                                 @SpringQueryMap LocationQueryParam param) {
        return merchantService.getMerchantDetail(id, param);
    }

    /**
     * 新增商家
     *
     * @param param 新增参数
     * @return 商家主键
     */
    @PostMapping("/merchant/addMerchant")
    public Long addMerchant(@RequestBody MerchantModifyParam param) {
        return merchantService.addMerchant(param);
    }

    /**
     * 修改商家
     *
     * @param id    商家主键
     * @param param 修改参数
     */
    @PutMapping("/merchant/updateMerchant")
    public void updateMerchant(@RequestParam("id") Long id, @RequestBody MerchantModifyParam param) {
        merchantService.updateMerchant(id, param);
    }

    /**
     * 删除商家
     *
     * @param id 商家主键
     */
    @DeleteMapping("/merchant")
    public void deleteMerchant(@RequestParam("id") Long id) {
        merchantService.deleteMerchant(id);
    }

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家分页信息
     */
    @GetMapping("/merchant/getMerchantPaging")
    public Pagination<MerchantDTO> getMerchantPaging(MerchantPagingParam param) {
        return merchantService.getMerchantPaging(param);
    }

    /**
     * 查询商家信息
     *
     * @param id 商家主键
     * @return 商家信息
     */
    @GetMapping("/merchant/getMerchant")
    public MerchantDTO getMerchant(@RequestParam("id") Long id) {
        return merchantService.getMerchant(id);
    }

    /**
     * 获取商家信息
     *
     * @return
     */
    @GetMapping("/merchant/getMerchantIdsByUserId")
    public List<MerchantDTO> getMerchantIdsByUserId() {
        return merchantService.getMerchantIdsByUserId();
    }

    /**
     * 查询商家排名
     *
     * @param param
     * @param userId
     * @return
     */
    @GetMapping("/merchant/listUserRankMerchants")
    public List<MerchantRankDTO> listUserRankMerchants(@SpringQueryMap MerchantRankParam param,
                                                       @RequestParam("userId") Long userId) {
        return merchantService.listRankMerchants(param, userId);
    }

    /**
     * 后台查询商家排名
     *
     * @param param
     * @return
     */
    @GetMapping("/merchant/listRankMerchants")
    public List<MerchantRankDTO> listRankMerchants(MerchantRankParam param) {
        return merchantService.listRankMerchants(param);
    }

    /**
     * 我的购物车列表
     *
     * @param param
     * @return
     */
    @GetMapping("/merchant/getUserMineCartPaging")
    public Pagination<MerchantDTO> getUserMineCartPaging(OmsCartItemPagingParam param) {
        return merchantService.getUserMineCartPaging(param);
    }

    /**
     * 更改商家得营业状态
     *
     * @param merchantId     商家ID
     * @param businessStatus 营业状态
     */
    @PutMapping("/merchant/updateMerchantBusinessStatus")
    public void updateMerchantBusinessStatus(@RequestParam("merchantId") Long merchantId,
                                             @RequestParam("businessStatus") String businessStatus) {
        merchantService.updateMerchantBusinessStatus(merchantId, businessStatus);
    }

    /**
     * 获取商家营业状况
     *
     * @return
     */
    @GetMapping("/merchant/operatConditions")
    public Map<String, Object> operatConditions() {
        return merchantService.operatConditions();
    }

    /**
     * 经营报表
     *
     * @return 经营报表信息
     */
    @GetMapping("/merchant/operatReport")
    public List<Map<String, Object>> operatReport(ReportModifyParam param) {
        return merchantService.operatReport(param);
    }

    /**
     * 商家审核
     *
     * @param id
     * @param status
     */
    @PostMapping("/merchant/merchantAudit")
    public void merchantAudit(@RequestParam("id") Long id, @RequestParam("status") MerchantStatus status) {
        merchantService.merchantAudit(id, status);
    }


    /**
     * 获取商家入驻统计
     *
     * @return
     */
    @GetMapping("/merchant/getMerchantReport")
    public List<Map<String, Object>> getMerchantReport(ReportModifyParam param) {
        return merchantService.getMerchantReport(param);
    }


    /**
     * 获取商家入驻统计
     *
     * @return
     */
    @GetMapping("/merchant/getMerchantReportCount")
    public Map<String, Object> getMerchantReportCount(ReportModifyParam param) {
        return merchantService.getMerchantReportCount(param);
    }
}



